@@ -9,12 +9,15 @@ from collections import namedtuple
 import torch.utils.model_zoo as model_zoo
 from collections import OrderedDict
 
+from .nasnet import NASNetAMobile
+
 Genotype = namedtuple('Genotype', 'normal normal_concat reduce reduce_concat')
 
 url_cfgs = {
     'dartsv2': 'https://github.com/jitdee-ai/darts-models/releases/download/0.0.1/dartv2.pt',
     'pdarts' : 'https://github.com/jitdee-ai/darts-models/releases/download/0.0.1/pdarts.pt',
     'relative_nas' : 'https://github.com/jitdee-ai/darts-models/releases/download/0.0.1/relative_nas.pt',
+    'nasnet' : 'https://github.com/jitdee-ai/darmo/releases/download/0.0.1/nasnetamobile-7e03cead.pth',
 }
 
 def _remove_module(state_dict):
@@ -38,48 +41,59 @@ def _set_config(_config={}, name=None, first_channels=48, layers=14, auxiliary=T
     return _config
 
 def _load_pre_trained(config):
-    base_net = NetworkImageNet(
-        config['first_channels'], 
-        config['num_classes'], 
-        config['layers'], 
-        config['auxiliary'], 
-        config['genotype'],
-        config['last_bn'])
+    if config['name'] == 'nasnet':
+        base_net = NASNetAMobile()
+    else:
+        base_net = NetworkImageNet(
+            config['first_channels'], 
+            config['num_classes'], 
+            config['layers'], 
+            config['auxiliary'], 
+            config['genotype'],
+            config['last_bn'])
 
     if config['pretrained']:
         state_dict = model_zoo.load_url(url_cfgs[config['name']], progress=True, map_location='cpu')
         try:
-            base_net.load_state_dict(state_dict, strict=True)
+            base_net.load_state_dict(state_dict, strict=False)
             print("loaded state dict")
         except RuntimeError:
-            base_net.load_state_dict(_remove_module(state_dict), strict=True)
+            base_net.load_state_dict(_remove_module(state_dict), strict=False)
             print("loaded state dict")
     return base_net
 
 @register_model
-def dartsv2(pretrained=True, num_classes=1000):
+def dartsv2(pretrained=True, num_classes=1000, auxiliary=True):
     dartsv2 = Genotype(normal=[('sep_conv_3x3', 0), ('sep_conv_3x3', 1), ('sep_conv_3x3', 0), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('skip_connect', 0), ('skip_connect', 0), ('dil_conv_3x3', 2)], normal_concat=[2, 3, 4, 5], reduce=[('max_pool_3x3', 0), ('max_pool_3x3', 1), ('skip_connect', 2), ('max_pool_3x3', 1), ('max_pool_3x3', 0), ('skip_connect', 2), ('skip_connect', 2), ('max_pool_3x3', 1)], reduce_concat=[2, 3, 4, 5])
-    config = _set_config(_config={}, name= 'dartsv2', first_channels=48, layers=14, auxiliary=True, 
+    config = _set_config(_config={}, name= 'dartsv2', first_channels=48, layers=14, auxiliary=auxiliary, 
                         genotype=dartsv2, last_bn=False, pretrained=pretrained, num_classes=num_classes)
 
     return _load_pre_trained(config)
 
 @register_model
-def pdarts(pretrained=True, num_classes=1000):
+def pdarts(pretrained=True, num_classes=1000, auxiliary=True):
 
     pdarts = Genotype(normal=[('skip_connect', 0), ('dil_conv_3x3', 1), ('skip_connect', 0),('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 3), ('sep_conv_3x3',0), ('dil_conv_5x5', 4)], normal_concat=range(2, 6), reduce=[('avg_pool_3x3', 0), ('sep_conv_5x5', 1), ('sep_conv_3x3', 0), ('dil_conv_5x5', 2), ('max_pool_3x3', 0), ('dil_conv_3x3', 1), ('dil_conv_3x3', 1), ('dil_conv_5x5', 3)], reduce_concat=range(2, 6))
 
-    config = _set_config(_config={}, name= 'pdarts', first_channels=48, layers=14, auxiliary=True, 
+    config = _set_config(_config={}, name= 'pdarts', first_channels=48, layers=14, auxiliary=auxiliary, 
                         genotype=pdarts, last_bn=True, pretrained=pretrained, num_classes=num_classes)
 
     return _load_pre_trained(config)
 
 @register_model
-def relative_nas(pretrained=True, num_classes=1000):
+def relative_nas(pretrained=True, num_classes=1000, auxiliary=True):
 
     relative_nas = Genotype( normal=[ ('sep_conv_3x3', 0), ('dil_conv_5x5', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_3x3', 1), ('sep_conv_5x5', 1), ('skip_connect', 0), ('sep_conv_3x3', 0) ], normal_concat=range(2, 6), reduce=[ ('avg_pool_3x3', 1), ('max_pool_3x3', 1), ('dil_conv_5x5', 1), ('max_pool_3x3', 1), ('avg_pool_3x3', 3), ('skip_connect', 1), ('dil_conv_5x5', 3), ('sep_conv_3x3', 1) ], reduce_concat=range(2, 6) )
     
-    config = _set_config(_config={}, name= 'relative_nas', first_channels=46, layers=14, auxiliary=True, 
+    config = _set_config(_config={}, name= 'relative_nas', first_channels=46, layers=14, auxiliary=auxiliary, 
                         genotype=relative_nas, last_bn=False, pretrained=pretrained, num_classes=num_classes)
 
+    return _load_pre_trained(config)
+
+@register_model
+def nasnet(pretrained=True, num_classes=1000, auxiliary=True):
+
+    config = _set_config(_config={}, name= 'nasnet', first_channels=46, layers=14, auxiliary=auxiliary, 
+                        genotype=None, last_bn=False, pretrained=pretrained, num_classes=num_classes)
+
     return _load_pre_trained(config)
\ No newline at end of file
