@@ -4,6 +4,7 @@ def create_model(
         model_name,
         pretrained=False,
         num_classes=1000,
+        auxiliary=True,
         **kwargs):
     """Create a model
     Args:
@@ -11,7 +12,7 @@ def create_model(
         pretrained (bool): load pretrained ImageNet-1k weights if true
         num_classes (int): number of classes for final fully connected layer (default: 1000)
     """
-    model_args = dict(pretrained=pretrained, num_classes=num_classes)
+    model_args = dict(pretrained=pretrained, num_classes=num_classes, auxiliary=auxiliary)
 
     # Parameters that aren't supported by all models or are intended to only override model defaults if set
     # should default to None in command line args/cfg. Remove them if they are present and not set so that
